@@ -19,6 +19,7 @@ KEY__pre_auth_key = "pre_auth_key"
 KEY__email = "email"
 KEY__sort = "sort"
 KEY__invite_key = "invite_key"
+KEY__sign_up_data = "sign_up_data"
 KEY__search = "search"
 KEY__application_name = "name"
 KEY__dataset = "dataset"
@@ -34,7 +35,6 @@ KEY__connection = "connection"
 KEY__node = "node"
 KEY__application_url = "url"
 KEY__role = "role"
-KEY__roles = "roles"
 KEY__mfa_key = "mfa_key"
 KEY__mfa_enabled = "mfa_enabled"
 KEY__username = "username"
@@ -59,6 +59,7 @@ KEY__jaaql_otp_uri = "jaaql_otp_uri"
 KEY__jaaql_otp_qr = "jaaql_otp_qr"
 KEY__superjaaql_otp_uri = "superjaaql_otp_uri"
 KEY__superjaaql_otp_qr = "superjaaql_otp_qr"
+KEY__is_public = "is_public"
 
 ATTR__deleted = "deleted"
 
@@ -89,6 +90,7 @@ SEPARATOR__space = " "
 JAAQL__arg_marker = ":"
 
 ENCODING__utf = "UTF-8"
+ENCODING__ascii = "ascii"
 EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-QRAjfe3eSosO949U73Vo"
 
-VERSION = "2.2.0"
+VERSION = "2.8.0"
